@@ -1,3 +1,7 @@
 from .reader import Reader
 
-read = Reader()
\ No newline at end of file
+read = Reader()
+
+__all__ = [
+    "read"
+]
\ No newline at end of file
