@@ -10,6 +10,6 @@ class AudioReader:
     @staticmethod
     def of(path: str, return_info: bool) -> Union[AudioData, AudioMetaData]:
         if return_info:
-            return torchaudio.backend.sox_io_backend.info(path)
+            return torchaudio.info(path)
         else:
-            return AudioData(*torchaudio.backend.sox_io_backend.load(path))
+            return AudioData(*torchaudio.load(path))
